#' Plot cases barplot
#' 
#' Produce pdf document containing a barplot showing the posterior expected number of cases attributed to each source. For use with the single attribution model. The vertical lines indicate 95\% credible intervals.
#' @param o The output list from the function \link{sourceAttribution}.  
#' @param file Filename of the output. Put file=NULL to plot to the current graphics device.
#' @param burnin Number of samples to discard as burnin (plus 1).
#' @param col Vector of colours for the different sources.
#' @details Source labels are taken from the attribute \code{rownames(X)}. 
#' @export
casesBarplot<-function(o,file="casesBarplot.pdf",burnin=501,col=NULL) {
  srcs<-dim(o$X)[1]
  typs<-dim(o$X)[2]
  yrs<-dim(o$Y)[1]
  if (!is.null(file)) {pdf(file,width=8,height=6)}
  if (is.null(col)) {col<-c("darkorange","blue","black","red","darkgreen","purple","grey")}
  if (length(col)<srcs) {col<-rep(col,srcs)}
  par(mfrow=c(1,1),mar=c(4, 4, 2, 1) + 0.1)
  pts<-burnin:length(o$theta.stored)
  rgbs<-col2rgb(col)
  thin.cols<-rep(NA,length(col))
  for (i in 1:length(col)) {
    thin.cols[i]<-rgb(rgbs[1,i],rgbs[2,i],rgbs[3,i],80,maxColorValue=255)
  }
  totcases<-apply(o$cases,c(2,3),sum)
  qcases<-apply(totcases[,pts],1,quantile,probs=c(0.025,0.5,0.975))
  mp<-barplot(qcases[2,], ylab="Number of human cases", ylim=c(0, max(qcases)), names=rownames(o$X), cex.lab=0.6, cex.names=0.6, cex.axis=0.6,
               main="Attribution of cases",col=thin.cols[1:srcs])
  hh<-segments(mp,qcases[1,],mp,qcases[3,],lwd=2)
  if (!is.null(file)) {dev.off()}
}