#' Output posterior expected number of cases attributed to each source.
#' 
#' Useful for making tables for papers.
#' @param o The output list from the function \link{sourceAttribution}.  
#' @param file Filename of the output.
#' @param burnin Number of samples to discard as burnin (plus 1).
#' @param dp Number of decimal places for the table.
#' @details Source labels are taken from the attribute \code{rownames(X)}. 
#' @export
casesTable<-function(o,file="casesTable.csv",burnin=501,dp=1) {
  srcs<-dim(o$X)[1]
  typs<-dim(o$X)[2]
  yrs<-dim(o$Y)[1]
  pts<-burnin:length(o$theta.stored)
  cat("Source,Posterior median cases,Lower 95% CI,Upper 95% CI\n",file=file,sep=",")
  totcases<-apply(o$cases,c(2,3),sum)
  qcases<-apply(totcases[,pts],1,quantile,probs=c(0.025,0.5,0.975))
  for (j in 1:srcs) {
    cat(rownames(o$X)[j],",",round(qcases[2,j],dp),",",round(qcases[1,j],dp),",",round(qcases[3,j],dp),"\n",append=TRUE,file=file,sep="")
  }
}