#' Plot model parameters
#' 
#' Produce pdf document containing trace plots and histograms of the source-specific factors, the strain-specific factors and the precision of the strain-specific factors in the posterior distribution.
#' @param o The output list from the function \link{sourceAttribution}.  
#' @param file Filename of the output.
#' @param burnin Number of samples to discard as burnin (plus 1).
#' @details The prior density is drawn in red over the histogram of posterior samples. 
#' @export
plotParameterFile<-function(o,file="parameters.pdf",burnin=501) {
  srcs<-dim(o$X)[1]
  typs<-dim(o$X)[2]
  yrs<-dim(o$Y)[1]
  pdf(file,paper="a4",height=12,width=8)
  par(mfrow=c(srcs,2),mar=c(4, 4, 2, 1) + 0.1)
  pts<-burnin:length(o$theta.stored)
  if (length(dim(o$a.stored))==2) {
    for (j in 1:srcs) {
      plot(pts,o$a.stored[j,pts],t="l",ylab=round(o$acceptance$a.accept[j]/(o$acceptance$a.accept[j]+o$acceptance$a.reject[j]),3),xlab="",main=paste("Source",j,rownames(o$X)[j]))
      hist(o$a.stored[j,pts],probability=TRUE,breaks=40,xlab="",main=paste("Source",j,rownames(o$X)[j]))
      ax<-seq(min(o$a.stored[j,pts]),max(o$a.stored[j,pts]),length.out=101)
      lines(ax,dexp(ax,o$priors$alpha[j]),col="red")
    }
  } else {
    for (k in 1:yrs) {
      for (j in 1:srcs) {
        plot(pts,o$a.stored[k,j,pts],t="l",ylab=round(o$acceptance$a.accept[k,j]/(o$acceptance$a.accept[k,j]+o$acceptance$a.reject[k,j]),3),xlab="",main=paste("Source",j,rownames(o$X)[j],rownames(o$Y)[k]))
        hist(o$a.stored[k,j,pts],probability=TRUE,breaks=40,xlab="",main=paste("Source",j,rownames(o$X)[j],rownames(o$Y)[k]))
        ax<-seq(min(o$a.stored[k,j,pts]),max(o$a.stored[k,j,pts]),length.out=101)
        lines(ax,dexp(ax,o$priors$alpha[j]),col="red")
      }
    }
  }
  plot(pts,o$theta.stored[pts],t="l",ylab="",xlab="",main="Precision of random effects theta")
  hist(o$theta.stored[pts],probability=TRUE,breaks=40,xlab="",main="Precision of random effects theta")
  ax<-seq(min(o$theta.stored[pts]),max(o$theta.stored[pts]),length.out=101)
  lines(ax,dgamma(ax,o$priors$theta.prior[1],o$priors$theta.prior[2]),col="red")
  for (i in 1:typs) {
    plot(pts,o$q.stored[i,pts],t="l",ylab="",xlab="",main=paste("Type",i,colnames(o$X)[i]))
    hist(o$q.stored[i,pts],probability=TRUE,breaks=40,xlab="",main=paste("Type",i,colnames(o$X)[i]))
    ax<-seq(min(o$q.stored[i,pts]),max(o$q.stored[i,pts]),length.out=101)
    lines(ax,dgamma(ax,median(o$theta.stored),median(o$theta.stored)),col="red")
  }
  dev.off()
}