#' Plot relative prevalences
#' 
#' Produce pdf document containing trace plots and histograms of the relative prevalences in the posterior distribution.
#' @param o The output list from the function \link{sourceAttribution}.  
#' @param file Filename of the output.
#' @param burnin Number of samples to discard as burnin (plus 1).
#' @details The prior density is drawn in red over the histogram of posterior samples. 
#' @export
plotPrevalenceFile<-function(o,file="prevalence.pdf",burnin=501) {
  srcs<-dim(o$X)[1]
  typs<-dim(o$X)[2]
  pdf(file,paper="a4",height=12,width=8)
  par(mfrow=c(7,2),mar=c(4, 4, 2, 1) + 0.1)
  pts<-burnin:length(o$theta.stored)
  for (j in 1:srcs) {
    for (i in 1:typs) {
      plot(pts,o$r.stored[j,i,pts],t="l",ylab=round(o$acceptance$r.accept[j,i]/(o$acceptance$r.accept[j,i]+o$acceptance$r.reject[j,i]),3),xlab="",main=paste("Source",j,rownames(o$X)[j]))
      hist(o$r.stored[j,i,pts],probability=TRUE,breaks=40,xlab="",main=paste("Type",i,colnames(o$X)[i]))
      ax<-seq(min(o$r.stored[j,i,pts]),max(o$r.stored[j,i,pts]),length.out=101)
      lines(ax,dbeta(ax,1+o$X[j,i],typs-1+sum(o$X[j,-i])),col="red")
    }
  }
  dev.off()
}