#' Count top strains in each source
#' 
#' Count the most represented strains in each source. Useful for exploring which strains contribute to the unobserved source.
#' @param o The output list from the function \link{sourceAttribution}.  
#' @param tops Number of strains to show (default is the 5 most represented strains).
#' @param burnin Number of samples to discard as burnin (plus 1).
#' @details Strain labels are taken from the attribute \code{colnames(X)}. 
#' @export
top<-function(o,tops=5, burnin=501) {
  srcs<-dim(o$X)[1]
  typs<-dim(o$X)[2]
  yrs<-dim(o$Y)[1]
  pts<-burnin:length(o$theta.stored)
  rw<-o$X/c(o$X%*%matrix(1,typs,1))
  for (j in 1:srcs) {
    mp<-apply(o$r.stored[j,,pts],1,mean)
    or<-order(mp,decreasing=TRUE)
    cat(rownames(o$X)[j],":\n")
    for (k in 1:tops) {
      cat("  ",round(mp[or[k]]*100,1),"%",colnames(o$X)[or[k]],"(raw",round(100*rw[j,or[k]],1),"%)\n")
    }
  }
}